<?php
/**
 * Tendu Drupal 5.x Theme For Developers CSS
 * $Id: template.php,v 1.3 2008/11/15 12:12:16 tombigel Exp $
 * Author: Tom Bigelajzen - http://tombigel.com
 * 
 * This theme is cross-browser and RTL ready.
 * It is extremely minimal and meant to be a wireframe for 
 * theme developers to build bi-directional themes.
 * 
 */

/**
 * LAnguage direction function
 * This function checks for languages that are written from right to left and returns
 * a string with the direction - "rtl" or "ltr".
 * @return Language Direction 
 */
function language_dir(){
  $lang = $GLOBALS['locale'];
  $dir = "ltr";     
  $rtl_langs = array("ar", "fa", "he", "ur", "yi"); // There are a couple or so more. Put the codes of your RTL languages here
  if (in_array ($lang, $rtl_langs)) { // Check if the language of the current page is RTL.
    $dir = "rtl";
  }
  return $dir;
}
/**
 * CSS Files 
 * Notes: 
 * The line that calls style.css is not necessary (it will be called anyway), 
 * but I leave it here anyway as an example.
 */ 
drupal_add_css(path_to_theme() .'/style.css', 'theme');

/**
 * Add RTL CSS Support 
 * Notes:
 * These CSS files will be called only for languages set to RTL
 */
if (language_dir() == 'rtl' ) { 
  drupal_add_css(path_to_theme() .'/style-rtl.css', 'theme');//Incremental RTL css rules for style.css
}

/**
 * Declare the available regions implemented by this theme.
 *
 * @return
 *   An array of regions.
 */

function tendu_regions() {
  return array(
    'sidebar_left' => t('left sidebar'),
    'sidebar_right' => t('right sidebar'),
    'content' => t('content'),
    'content_top' => t('content top'),
    'content_bottom' => t('content bottom'),
    'header' => t('header'),
    'footer' => t('footer'),
	'main_nav' => t('main navagation'),
  );
}

/**
 * Style Language links (i18n Package)
 * This function restyles the language links for the i18n module
 * Note: Tendu does not rely on i18n anymore, this function remained here for backwords compatibility reoasons67
 * If you do not require the "Language switcher" you can delete it. 
 * @return
 *   HTML of the links
 */
function tendu_i18n_link($text, $target, $lang, $separator='&nbsp;'){
  $output = '<span class="i18n-link">';
  $attributes = ($lang == i18n_get_lang()) ? array('class' => 'active') : NULL;
  //$output .= l(theme('i18n_language_icon', $lang), $target, $attributes, NULL, NULL, FALSE, TRUE);//Flags
  $output .= $separator;
  // $output .= l($text, $target, $attributes, NULL, NULL, FALSE, TRUE);
  $output .= l(t($text), $target, $attributes, NULL, NULL, FALSE, TRUE);//Text
  $output .= '</span>';
  return $output;
}


/**
 * Override or insert PHPTemplate variables into the page templates.
 *
 * @param $vars
 *   A sequential array of variables to pass to the theme template.
 */
function _phptemplate_variables($hook, $vars=array() ) {
  switch ($hook) {
    case 'page':
      /* Add classes to the "body" tag, for easier layout styling
      * Idea taken from ZEN theme (but my changes make it incompatible with it)
      */
      $body_classes = array();
      // Page user is logged in
      $body_classes[] = ($vars['logged_in']) ? 'logged-in' : 'not-logged-in';
      // Page is front page
      $body_classes[] = ($vars['is_front']) ? 'front' : 'not-front'; 
      
      //Clean these strings from special characters (TODO: do we need this check?)
      $_page_type = str_replace(array('][', '_', ' '), '-', arg(0));
      $_node_type = str_replace(array('][', '_', ' '), '-', $vars['node']->type);
      // Page type (for admin, node, etc.)
      $body_classes[] = preg_replace('![^abcdefghijklmnopqrstuvwxyz0-9-_]+!s', '', 'page-' . $_page_type);
      //If node page, print node type
      if (isset($vars['node']) && $vars['node']->type) {
        $body_classes[] = 'node-type-'. $_node_type;
      }
      
      //Add classes depended on sidebars
      if ($vars['sidebar_left'] && $vars['sidebar_right']) {
        $body_classes[] = 'two-sidebars';
      } elseif (!$vars['sidebar_left'] && !$vars['sidebar_right']){
        $body_classes[] = 'no-sidebars';
      } else{
        $body_classes[] = 'one-sidebar';
      }
    
      if ($vars['sidebar_left']) {
        $body_classes[] = 'with-sidebar-left';
      }
      if ($vars['sidebar_right']) {
        $body_classes[] = 'with-sidebar-right';
      }
	  $vars['body_classes'] = implode(' ', $body_classes); // Concatenate with spaces
	  	  
	  //Add rtl/ltr variable to page.tpl      
      $vars['language_dir'] = language_dir();     
    break;
  }
  return $vars;
}